@@ -1,11 +1,11 @@
 #[macro_use]
 extern crate redis_module;
 
-use redis_module::{Context, LogLevel, Status};
+use redis_module::{Context, LogLevel, RedisString, Status};
 
 static mut GLOBAL_STATE: Option<String> = None;
 
-fn init(ctx: &Context, args: &Vec<String>) -> Status {
+fn init(ctx: &Context, args: &Vec<RedisString>) -> Status {
     let (before, after) = unsafe {
         let before = GLOBAL_STATE.clone();
         GLOBAL_STATE.replace(format!("Args passed: {}", args.join(", ")));
