@@ -53,12 +53,18 @@ impl Context {
         self.log(LogLevel::Warning, message);
     }
 
+    /// # Panics
+    ///
+    /// Will panic if `RedisModule_AutoMemory` is missing in redismodule.h
     pub fn auto_memory(&self) {
         unsafe {
             raw::RedisModule_AutoMemory.unwrap()(self.ctx);
         }
     }
 
+    /// # Panics
+    ///
+    /// Will panic if `RedisModule_IsKeysPositionRequest` is missing in redismodule.h
     pub fn is_keys_position_request(&self) -> bool {
         // We want this to be available in tests where we don't have an actual Redis to call
         if cfg!(feature = "test") {
@@ -70,6 +76,9 @@ impl Context {
         result != 0
     }
 
+    /// # Panics
+    ///
+    /// Will panic if `RedisModule_KeyAtPos` is missing in redismodule.h
     pub fn key_at_pos(&self, pos: i32) {
         // TODO: This will crash redis if `pos` is out of range.
         // Think of a way to make this safe by checking the range.
@@ -125,6 +134,9 @@ impl Context {
         }
     }
 
+    /// # Panics
+    ///
+    /// Will panic if methods used are missing in redismodule.h
     pub fn reply(&self, r: RedisResult) -> raw::Status {
         match r {
             Ok(RedisValue::Integer(v)) => unsafe {
@@ -153,6 +165,19 @@ impl Context {
                 .into()
             },
 
+            Ok(RedisValue::BulkRedisString(s)) => unsafe {
+                raw::RedisModule_ReplyWithString.unwrap()(self.ctx, s.inner).into()
+            },
+
+            Ok(RedisValue::StringBuffer(s)) => unsafe {
+                raw::RedisModule_ReplyWithStringBuffer.unwrap()(
+                    self.ctx,
+                    s.as_ptr() as *const i8,
+                    s.len() as usize,
+                )
+                .into()
+            },
+
             Ok(RedisValue::Array(array)) => {
                 unsafe {
                     // According to the Redis source code this always succeeds,
@@ -199,15 +224,11 @@ impl Context {
         }
     }
 
-    pub fn open_key(&self, key: &str) -> RedisKey {
+    pub fn open_key(&self, key: &RedisString) -> RedisKey {
         RedisKey::open(self.ctx, key)
     }
 
-    pub fn open_with_redis_string(&self, key: *mut raw::RedisModuleString) -> RedisKeyWritable {
-        RedisKeyWritable::open_with_redis_string(self.ctx, key)
-    }
-
-    pub fn open_key_writable(&self, key: &str) -> RedisKeyWritable {
+    pub fn open_key_writable(&self, key: &RedisString) -> RedisKeyWritable {
         RedisKeyWritable::open(self.ctx, key)
     }
 
@@ -237,7 +258,7 @@ impl Context {
         &self,
         event_type: raw::NotifyEvent,
         event: &str,
-        keyname: &str,
+        keyname: &RedisString,
     ) -> raw::Status {
         raw::notify_keyspace_event(self.ctx, event_type, event, keyname)
     }
